@@ -31,7 +31,7 @@
 
 #include <stdio.h>
 #include <ctype.h>
-#if !defined(_WIN32)
+#if !defined(_WIN32) && !defined(_WIN64)
 # include <pwd.h>
 #else
 # include <stdlib.h>
@@ -44,10 +44,9 @@
 #include <unistd.h>
 #endif
 
-#if defined(__MSDOS__)
+#if defined(_WIN32) || defined(_WIN64)
 #include <limits.h>
 #define _fullpath(f,n,s) (_fixpath(n,f),f)
-#define MSDOS_MAX_PATH PATH_MAX
 #endif
 
 #include "calc.h"
@@ -407,11 +406,11 @@ f_pathopen(char *name, char *mode, char *pathlist, char **openpath)
 S_FUNC char *
 homeexpand(char *name)
 {
-#if defined(_WIN32)
+#if defined(_WIN32) || defined(_WIN64)
 
 	return NULL;
 
-#else /* Windoz free systems */
+#else /* Windows free systems */
 
 	struct passwd *ent;	/* password entry */
 	char *home2;		/* fullpath of the home directory */
@@ -483,7 +482,7 @@ homeexpand(char *name)
 	snprintf(fullpath, snprintf_len, "%s%s", home2, after);
 	fullpath[snprintf_len] = '\0';	/* paranoia */
 	return fullpath;
-#endif /* Windoz free systems */
+#endif /* Windows free systems */
 }
 
 
@@ -603,7 +602,7 @@ curstream(void)
  *
  * given:
  *	str		string to be opened
- *	num		lengh of string to open
+ *	num		length of string to open
  */
 int
 openstring(char *str, size_t num)
@@ -969,13 +968,14 @@ runrcfiles(void)
  * a given device/inode, -1 otherwise.
  *
  *
- * WIN32 NOTE:
+ * _WIN32 and _WIN64 NOTE:
  *
- *	This function does not work under WIN32. The sbuf->st_ino is always
- *	zero because the FAT and NTFS filesystems do not support inodes.
- *	They also don't support links, which is why you need this function
- *	under UNIX. For WIN32, use _fullpath() to determine if you have
- *	already opened a file.
+ *	This function likely will not work under _WIN32 or _WIN64.
+ *
+ *	The sbuf->st_ino is always zero because the FAT and NTFS filesystems
+ *	do not support inodes.  Those filesystems don't support links, which
+ *	is why you need this function under UNIX. For _WIN32 or _WIN64, use
+ *	_fullpath() to determine if you have already opened a file.
  *
  * given:
  *	sbuf		stat of the inode in question
@@ -994,23 +994,23 @@ isinoderead(struct stat *sbuf)
 
 	/* scan the entire readset */
 	for (i=0; i < maxreadset; ++i) {
-#if defined(_WIN32) || defined(__MSDOS__)
-		char tmp[MSDOS_MAX_PATH+1];
-		tmp[MSDOS_MAX_PATH] = '\0';
-		if (_fullpath(tmp, cip->i_name, MSDOS_MAX_PATH) &&
+#if defined(_WIN32) || defined(_WIN64)
+		char tmp[MAX_PATH+1];
+		tmp[MAX_PATH] = '\0';
+		if (_fullpath(tmp, cip->i_name, MAX_PATH) &&
 		    readset[i].active &&
 		    strcasecmp(readset[i].path, tmp) == 0) {
 			/* found a match */
 			return i;
 		}
-#else /* Windoz free systems */
+#else /* Windows free systems */
 		if (readset[i].active &&
 		    sbuf->st_dev == readset[i].inode.st_dev &&
 		    sbuf->st_ino == readset[i].inode.st_ino) {
 			/* found a match */
 			return i;
 		}
-#endif /* Windoz free systems */
+#endif /* Windows free systems */
 	}
 
 	/* no match found */
@@ -1120,27 +1120,27 @@ addreadset(char *name, char *path, struct stat *sbuf)
 		return -1;
 	}
 	strlcpy(readset[ret].name, name, name_len+1);
-#if defined(_WIN32) || defined(__MSDOS__)
+#if defined(_WIN32) || defined(_WIN64)
 	/*
-	 * For WIN32, _fullpath expands the path to a fully qualified
-	 * path name, which under WIN32 FAT and NTFS is unique, just
+	 * For _WIN32 or _WIN64, _fullpath expands the path to a fully qualified
+	 * path name, which under _WIN32 or _WIN64 FAT and NTFS is unique, just
 	 * like UNIX inodes. _fullpath also allocated the memory for
 	 * this new longer path name.
 	 */
 	 {
-		readset[ret].path = _fullpath(NULL, path, MSDOS_MAX_PATH);
+		readset[ret].path = _fullpath(NULL, path, MAX_PATH);
 		if (readset[ret].path == NULL) {
 			return -1;
 		}
 	 }
-#else /* Windoz free systems */
+#else /* Windows free systems */
 	path_len = strlen(path);
 	readset[ret].path = (char *)malloc(path_len+1);
 	if (readset[ret].path == NULL) {
 		return -1;
 	}
 	strlcpy(readset[ret].path, path, path_len+1);
-#endif /* Windoz free systems */
+#endif /* Windows free systems */
 	readset[ret].inode = *sbuf;
 	readset[ret].active = 1;
 
