@@ -29,7 +29,7 @@
 #include <setjmp.h>
 #include <signal.h>
 
-#if !defined(_WIN32)
+#if !defined(_WIN32) && !defined(_WIN64)
 # include <pwd.h>
 #endif
 
@@ -84,14 +84,14 @@ typedef struct {int fd;} ttystruct;
 
 #endif
 
-#if !defined(_WIN32)
+#if !defined(_WIN32) && !defined(_WIN64)
 # if !defined(USE_SGTTY) && !defined (USE_TERMIOS) && !defined(USE_TERMIO)
 
--=*#*=- A Windoz free system without termio, termios or sgtty!!! -=*#*=-
+-=*#*=- A Windows free system without termio, termios or sgtty!!! -=*#*=-
 -=*#*=- We do not know how to compile for such a host, sorry!!!! -=*#*=-
 
 # endif
-#endif /* Windoz */
+#endif /* Windows */
 
 
 #include "banned.h"	/* include after system header <> includes */
@@ -240,7 +240,7 @@ libcalc_call_me_first(void)
 	 * Disable SIGPIPE so that the pipe to the help file pager will
 	 * not stop calc.
 	 */
-#if !defined(_WIN32)
+#if !defined(_WIN32) && !defined(_WIN64)
 	(void) signal(SIGPIPE, SIG_IGN);
 #endif
 
@@ -249,7 +249,7 @@ libcalc_call_me_first(void)
 	 */
 	if (program != NULL) {
 		p = strrchr(program, '/');
-#if defined(_WIN32) || defined(__MSDOS__)
+#if defined(_WIN32) || defined(_WIN64)
 		if (p == NULL) {
 			p = strrchr(program, '\\');
 		}
@@ -481,7 +481,7 @@ cvmalloc_error(char *message)
 S_FUNC void
 initenv(void)
 {
-#if !defined(_WIN32)
+#if !defined(_WIN32) && !defined(_WIN64)
 	struct passwd *ent;		/* our password entry */
 #endif
 	char *c;
@@ -512,7 +512,7 @@ initenv(void)
 	/* determine the $HOME value */
 	c = (no_env ? NULL : getenv(HOME));
 	home = (c ? strdup(c) : NULL);
-#if defined(_WIN32)
+#if defined(_WIN32) || defined(_WIN64)
 	if (home == NULL || home[0] == '\0') {
 		/* free home if it was previously allocated, but empty */
 		if (home != NULL) {
@@ -521,7 +521,7 @@ initenv(void)
 		/* just assume . is home if all else fails */
 		home = strdup(".");
 	}
-#else /* Windoz free systems */
+#else /* Windows free systems */
 	if (home == NULL || home[0] == '\0') {
 		/* free home if it was previously allocated, but empty */
 		if (home != NULL) {
@@ -538,7 +538,7 @@ initenv(void)
 			home = strdup(ent->pw_dir);
 		}
 	}
-#endif /* Windoz free systems */
+#endif /* Windows free systems */
 	/* paranoia */
 	if (home == NULL) {
 		math_error("Unable to allocate string for $HOME");
