@@ -285,7 +285,7 @@ printtype(VALUE *vp)
 		s = "file id";
 		break;
 	case V_RAND:
-		s = "additive 55 random state";
+		s = "subtractive 100 random state";
 		break;
 	case V_RANDOM:
 		s = "Blum random state";
@@ -573,7 +573,7 @@ showstatics(void)
 	if (count > 0)
 		printf("\nNumber: %ld\n", count);
 	else
-		printf("No unscoped static variables\n");
+		printf("No un-scoped static variables\n");
 }
 
 /*
